Implicit Mount Module
=====================

This module contains the main classes for establishing SFTP connections and performing file operations on remote servers. 
It uses LFTP for high-performance file transfers and provides a Pythonic interface for remote file operations.

.. automodule:: pyremotedata.implicit_mount
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource